@@ -140,6 +140,18 @@ class FilesystemRegexFinderTest(TestCase):
         )
 
 
+    @override_settings(JSTEMPLATE_DIRS=[os.path.join(here, "templates")])
+    def test_find_files_in_subdirectories(self):
+        self.assertEqual(
+            set(self.finder.find('(subdirectory.*)')),
+            set([('subdirectory/subdirectory2/testtemplate', os.path.join(here, 'templates', 'subdirectory', 'subdirectory2', 'testtemplate.html')),
+                 ('subdirectory/testtemplate', os.path.join(here, 'templates', 'subdirectory', 'testtemplate.html'))]))
+
+
+    @override_settings(JSTEMPLATE_DIRS=[os.path.join(here, "templates")])
+    def test_fails_silently_on_invalid_reges(self):
+        self.assertEqual(self.finder.find("*"), [])
+
 class AppFinderTest(TestCase):
     @property
     def finder(self):
